@@ -106,8 +106,7 @@ void ItemContainer::setEditMode(bool editMode)
 
     m_editMode = editMode;
 
-    // Leave this decision to QML?
-    if (m_editModeCondition != AfterMouseOver || m_layout->editMode()) {
+    if (m_editModeCondition != AfterMouseOver || (m_layout && m_layout->editMode())) {
         m_contentItem->setEnabled(!editMode);
     }
 
@@ -153,7 +152,7 @@ void ItemContainer::setEditModeCondition(EditModeCondition condition)
 
     m_editModeCondition = condition;
 
-    setAcceptHoverEvents(condition == AfterMouseOver);
+    setAcceptHoverEvents(condition == AfterMouseOver || (m_layout && m_layout->editMode()));
 
     emit editModeConditionChanged();
 }
@@ -182,6 +181,7 @@ void ItemContainer::setLayout(AppletsLayout *layout)
 
     if (m_layout) {
         disconnect(m_layout, &AppletsLayout::editModeConditionChanged, this,  nullptr);
+        disconnect(m_layout, &AppletsLayout::editModeChanged, this,  nullptr);
 
         if (m_editMode) {
             m_layout->hidePlaceHolder();
@@ -208,6 +208,9 @@ void ItemContainer::setLayout(AppletsLayout *layout)
             emit editModeConditionChanged();
         }
     });
+    connect(m_layout, &AppletsLayout::editModeChanged, this, [this]() {
+        setAcceptHoverEvents(m_editModeCondition == AfterMouseOver || m_layout->editMode());
+    });
     emit layoutChanged();
 }
 
@@ -392,7 +395,7 @@ void ItemContainer::geometryChanged(const QRectF &newGeometry, const QRectF &old
 void ItemContainer::componentComplete()
 {
     if (!m_contentItem) {
-        //qWarning()<<"Creting default contentItem";
+        //qWarning()<<"Creating default contentItem";
         m_contentItem = new QQuickItem(this);
         syncChildItemsGeometry(size());
     }
@@ -439,7 +442,7 @@ void ItemContainer::sendUngrabRecursive(QQuickItem *item)
 
     QEvent ev(QEvent::UngrabMouse);
 
-    item->window()->sendEvent(item, &ev);
+    QCoreApplication::sendEvent(item, &ev);
 }
 
 bool ItemContainer::childMouseEventFilter(QQuickItem *item, QEvent *event)
@@ -526,6 +529,7 @@ void ItemContainer::mousePressEvent(QMouseEvent *event)
 
     if (m_editMode) {
         grabMouse();
+        setCursor(Qt::ClosedHandCursor);
         m_dragActive = true;
         emit dragActiveChanged();
     } else if (m_editModeCondition == AfterPressAndHold) {
@@ -559,6 +563,7 @@ void ItemContainer::mouseReleaseEvent(QMouseEvent *event)
     m_dragActive = false;
     if (m_editMode) {
         emit dragActiveChanged();
+        setCursor(Qt::OpenHandCursor);
     }
     event->accept();
 }
@@ -625,7 +630,7 @@ void ItemContainer::hoverEnterEvent(QHoverEvent *event)
 {
     Q_UNUSED(event);
 
-    if (m_editModeCondition != AfterMouseOver) {
+    if (m_editModeCondition != AfterMouseOver && !m_layout->editMode()) {
         return;
     }
 
@@ -633,14 +638,19 @@ void ItemContainer::hoverEnterEvent(QHoverEvent *event)
         m_closeEditModeTimer->stop();
     }
 
-    m_editModeTimer->start(QGuiApplication::styleHints()->mousePressAndHoldInterval());
+    if (m_layout->editMode()) {
+        setCursor(Qt::OpenHandCursor);
+        setEditMode(true);
+    } else {
+        m_editModeTimer->start(QGuiApplication::styleHints()->mousePressAndHoldInterval());
+    }
 }
 
 void ItemContainer::hoverLeaveEvent(QHoverEvent *event)
 {
     Q_UNUSED(event);
 
-    if (m_editModeCondition != AfterMouseOver) {
+    if (m_editModeCondition != AfterMouseOver && !m_layout->editMode()) {
         return;
     }
 
